@@ -27,7 +27,7 @@
 # the code is not totally portable due to classpath and directory splitting
 # issues. oops. (NB, use File::Spec::Functions  will help and the code is
 # structured for the catfile() call, but because of perl version funnies
-# the code is not included. 
+# the code is not included.
 #######################################################################
 #
 # Assumptions:
@@ -47,7 +47,7 @@ use strict;
 #use warnings;
 
 #and set $debug to 1 to turn on trace info
-my $debug=1;
+my $debug = 1;
 
 #######################################################################
 #
@@ -55,43 +55,34 @@ my $debug=1;
 #
 
 my $HOME = $ENV{ANT_HOME};
-if ($HOME eq "")
-        {
+if (!$HOME) {
     die "\n\nANT_HOME *MUST* be set!\n\n";
-        }
-
-my $JAVACMD = $ENV{JAVACMD};
-$JAVACMD = "java" if $JAVACMD eq "";
-
-my $onnetware = 0;
-if ($^O eq "NetWare")
-{
-  $onnetware = 1;
 }
 
+my $JAVACMD = $ENV{JAVACMD} || "java";
+
+my $onnetware = ($^O eq "NetWare");
+
 my $oncygwin = ($^O eq "cygwin");
 
-#ISSUE: what java wants to split up classpath varies from platform to platform 
+#ISSUE: what java wants to split up classpath varies from platform to platform
 #and perl is not too hot at hinting which box it is on.
 #here I assume ":" 'cept on win32, dos, and netware. Add extra tests here as needed.
-my $s=":";
-if(($^O eq "MSWin32") || ($^O eq "dos") || ($^O eq "cygwin") ||
-   ($onnetware == 1))
-        {
-        $s=";";
-        }
+my $s = ":";
+if (($^O eq "MSWin32") || ($^O eq "dos") || $oncygwin || $onnetware) {
+    $s = ";";
+}
 
 #build up standard classpath
 my $localpath = "_antlibs_/ant-launcher.jar";
 #set JVM options and Ant arguments, if any
-my @ANT_OPTS=split(" ", $ENV{ANT_OPTS});
-my @ANT_ARGS=split(" ", $ENV{ANT_ARGS});
+my @ANT_OPTS = split(" ", $ENV{ANT_OPTS});
+my @ANT_ARGS = split(" ", $ENV{ANT_ARGS});
 
 #jikes
-if($ENV{JIKESPATH} ne "")
-        {
-        push @ANT_OPTS, "-Djikes.class.path=$ENV{JIKESPATH}";
-        }
+if ($ENV{JIKESPATH}) {
+    push @ANT_OPTS, "-Djikes.class.path=$ENV{JIKESPATH}";
+}
 
 #construct arguments to java
 my @ARGS;
@@ -99,52 +90,43 @@ push @ARGS, @ANT_OPTS;
 
 my $CYGHOME = "";
 
-my $classpath=$ENV{CLASSPATH};
-if ($oncygwin == 1) {
-  $localpath = `cygpath --path --windows $localpath`;
-  chomp ($localpath);
-  if (! $classpath eq "")
-  {
-    $classpath = `cygpath --path --windows "$classpath"`;
-    chomp ($classpath);
-  }
-  $HOME = `cygpath --path --windows $HOME`;
-  chomp ($HOME);
-  $CYGHOME = `cygpath --path --windows $ENV{HOME}`;
-  chomp ($CYGHOME);
+my $classpath = $ENV{CLASSPATH};
+if ($oncygwin) {
+    $localpath = `cygpath --path --windows $localpath`;
+    chomp ($localpath);
+    if ($classpath) {
+        $classpath = `cygpath --path --windows "$classpath"`;
+        chomp ($classpath);
+    }
+    $HOME = `cygpath --path --windows $HOME`;
+    chomp ($HOME);
+    $CYGHOME = `cygpath --path --windows $ENV{HOME}`;
+    chomp ($CYGHOME);
 }
 push @ARGS, "-classpath", "$localpath";
 push @ARGS, "-Dant.home=$HOME";
-if ( ! $CYGHOME eq "" )
-{
-  push @ARGS, "-Dcygwin.user.home=\"$CYGHOME\""
+if ($CYGHOME) {
+    push @ARGS, "-Dcygwin.user.home=\"$CYGHOME\""
 }
 push @ARGS, "org.apache.tools.ant.launch.Launcher", @ANT_ARGS;
 push @ARGS, @ARGV;
-if (! $classpath eq "")
-{
-  if ($onnetware == 1)
-  {
-    # make classpath literally $CLASSPATH
-    # this is to avoid pushing us over the 512 character limit
-    # even skip the ; - that is already in $localpath
-    push @ARGS, "-lib", "\$CLASSPATH";
-  }
-  else
-  {
-    push @ARGS, "-lib", "$classpath";
-  }
+if ($classpath) {
+    if ($onnetware) {
+        # make classpath literally $CLASSPATH
+        # this is to avoid pushing us over the 512 character limit
+        # even skip the ; - that is already in $localpath
+        push @ARGS, "-lib", "\$CLASSPATH";
+    } else {
+        push @ARGS, "-lib", "$classpath";
+    }
 }
 print "\n $JAVACMD @ARGS\n\n" if ($debug);
 
 my $returnValue = system $JAVACMD, @ARGS;
-if ($returnValue eq 0)
-        {
-        exit 0;
-        }
-else
-        {
-        # only 0 and 1 are widely recognized as exit values
-        # so change the exit value to 1
-        exit 1;
-        }
+if ($returnValue eq 0) {
+    exit 0;
+} else {
+    # only 0 and 1 are widely recognized as exit values
+    # so change the exit value to 1
+    exit 1;
+}
